#
# spec file for package netcfg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           netcfg
Version:        11.6
Release:        13.4
Summary:        Network Configuration Files in /etc
License:        BSD-3-Clause
Group:          System/Base
Source1:        exports
Source3:        host.conf
Source4:        hosts
Source9:        networks
Source10:       protocols
Source11:       services.bz2
Source12:       hostname
Source13:       aliases
Source16:       COPYING
Source17:       ethertypes
Source100:      services-compare.pl
Source101:      services-compare.sh
Source102:      services-create.pl
Source103:      services_UPDATING
Patch0:         services-suse.diff
BuildRequires:  libnss_usrfiles2
Requires:       libnss_usrfiles2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
All of the basic configuration files for the network programs including
%{_sysconfdir}/aliases, %{_sysconfdir}/protocols, and %{_sysconfdir}/services.

These are often used by network routines in the C library and therefore
must be installed for all network programs.

%prep

%build
cp %{SOURCE16} .

%install
mkdir -p %{buildroot}%{_sysconfdir}
for i in hostname aliases exports host.conf hosts ethertypes; do
  install $RPM_SOURCE_DIR/$i %{buildroot}/%{_sysconfdir}
done
mkdir -p %{buildroot}%{_prefix}%{_sysconfdir}
for i in networks protocols services.bz2; do
  install $RPM_SOURCE_DIR/$i %{buildroot}%{_prefix}%{_sysconfdir}
done
bunzip2 %{buildroot}%{_prefix}%{_sysconfdir}/services.bz2
patch -p0 %{buildroot}%{_prefix}%{_sysconfdir}/services < $RPM_SOURCE_DIR/services-suse.diff
rm -f %{buildroot}%{_prefix}%{_sysconfdir}/services.orig

install -d -m 0755 %{buildroot}/%{_sysconfdir}/exports.d

%files
%defattr(644,root,root,755)
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/hostname
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/aliases
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/exports
%config(noreplace) %{_sysconfdir}/host.conf
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/hosts
%{_prefix}%{_sysconfdir}/networks
%{_prefix}%{_sysconfdir}/protocols
%{_prefix}%{_sysconfdir}/services
%config(noreplace) %{_sysconfdir}/ethertypes
%dir %{_sysconfdir}/exports.d
%license COPYING

%changelog
* Mon Jan  1 2024 Martin Schreiner <martin.schreiner@suse.com>
- Add krb-prop entry, fix for bsc#1211886.
* Tue Nov 21 2023 Thorsten Kukuk <kukuk@suse.com>
- Fix syntax of localhost entries in hosts [bsc#1217355]
* Mon Nov 20 2023 Thorsten Kukuk <kukuk@suse.com>
- Remove empty netgroup example file from /etc [jsc#PED-240].
  NIS, the main consumer, got already dropped.
- Remove empty ethers example file, /usr/etc should not contain
  examples, for the format there is the manual page, does not
  support IPv6.
* Wed Oct  4 2023 Thorsten Kukuk <kukuk@suse.com>
- Remove ftpusers, none of our ftp servers uses that anymore
- Remove defaultdomain, NIS got dropped
* Tue Sep 26 2023 Thorsten Kukuk <kukuk@suse.com>
- Remove hosts.equiv and hosts.lpd, the tools using them got
  dropped long ago.
* Tue Oct 11 2022 Danilo Spinella <danilo.spinella@suse.com>
- Remove hosts.allow and hosts.deny config files as they are only
  used by tcpd, which is not installed by default, bsc#1099755
* Mon Jul 19 2021 Danilo Spinella <danilo.spinella@suse.com>
- Add localhost.localdomain fallback hostname used by NetworkManager
  (bsc#1177835).
* Thu Feb 18 2021 Johannes Segitz <jsegitz@suse.com>
- services-create.pl: Switch to https (bsc#1182395)
* Mon May 18 2020 Marketa Calabkova <mcalabkova@suse.com>
- Create /etc/exports.d directory (boo#1094328)
* Wed Feb  5 2020 Thorsten Kukuk <kukuk@suse.com>
- Require libnss_usrfiles2 for /usr/etc [bnc#1162666]
* Tue Jan 28 2020 Thorsten Kukuk <kukuk@suse.com>
- Re-add host.conf with fixed comments, only remove libc 4/5
  comments/entries.
* Fri Dec  6 2019 Thorsten Kukuk <kukuk@suse.com>
- Remove host.conf, nothing is using that anymore
* Mon Aug 19 2019 kukuk@suse.de
- Move ethers, networks, protocols and services to /usr/etc
* Wed Apr 17 2019 kukuk@suse.de
- Remove pre/post install to get rid of coreutils dependency.
  We don't support upgrading of this old code anymore and coreutils
  is not wanted in busybox containers.
- Update services.bz2
* Wed Sep 12 2018 Thorsten Kukuk <kukuk@suse.de>
- Don't create /etc/HOSTNAME symlink anymore, the expected content
  is slightly different from /etc/hostname [bsc#972463]
* Mon Jul  2 2018 tchvatal@suse.com
- Tell users to really install tcpd if they expects hosts.* to work
  bsc#1099755
* Thu Feb 22 2018 matthias.gerstner@suse.com
- Include /etc/ethertypes to resolve a conflict between
  security:netfilter/ebtables and security:netfilter/iptables-nft. This
  ethertypes version comes from iptables, because it contains an additional
  entry over the ebtables one. Increased minor version to allow a suitable
  Requires statement in ebtables/iptables. FATE#320520
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Tue Mar  7 2017 tchvatal@suse.com
- Update script to generage services to use UTF8 by default bsc#1028305
- Update the services list with latest content
* Tue Jan  5 2016 tchvatal@suse.com
- Repack services.bz2 with latest from upstream and adjust the script
  to not add all the names+emails at the bottom bnc#959693
* Tue Aug 25 2015 tchvatal@suse.com
- Do not actually replace the hostname if user already has something
  in there. Thanks to Takashi Iwai for spotting this
* Tue Aug  4 2015 tchvatal@suse.com
- Do not ghost the empty /etc/hostname to not break installationimages
  pkg.
* Thu Jun 11 2015 tchvatal@suse.com
- Keep /etc/hostname empty and %%ghost it. bnc#934056
* Wed Dec 17 2014 tchvatal@suse.com
- Try different approach to fix failing migration from 13.1.
  This one is from locilka
* Wed Dec 17 2014 tchvatal@suse.com
- Keep the condition posix as it is shorter :)
* Mon Dec  1 2014 tchvatal@suse.com
- Spec-cleanify the previous commit.
* Mon Dec  1 2014 tchvatal@suse.com
- Redo the HOSTNAME -> hostname migration to support smallest
  possible step. Thus ensuring the migration is done just once and
  finished:
  [#] HOSTNAME migration supported scenarios [bnc#858908]:
  [#] /etc/HOSTNAME -> /etc/hostname content preservation.
  [#] If hostname and HOSTNAME both exist HOSTNAME wins.
  [#] Nothing apart from content of the document is preserved
- Solves bnc#858908 and bnc#899506 while moves bnc#887039 to
  unsupported scenarios.
* Mon Dec  1 2014 tchvatal@suse.com
- Remove the socket check from the defaultdomain checker as it was
  always false and thus not needed
  - Add comment explaining the reason for the code
* Mon Dec  1 2014 tchvatal@suse.com
- Drop the scriptlet for the netgroup handling. It was caused by
  the aaa_base -> netcfg move, which I guess after 12 years is moot
* Thu Oct  2 2014 pgajdos@suse.com
- fix %%pre scriptlet [bnc#899506] (thanks to mls for the fix)
* Fri Jul 25 2014 pgajdos@suse.com
- resolve some update scenarios [bnc#883999], [bnc#886443] (private)
  with regard to /etc/HOSTNAME -> /etc/hostname change
* Wed Jun 11 2014 pgajdos@suse.com
- move /etc/HOSTNAME to /etc/hostname during update
* Wed Jun  4 2014 pgajdos@suse.com
- HOSTNAME renamed to hostname [bnc#858908]
* Thu Feb  6 2014 pgajdos@suse.com
- added helper scripts and doc for creating services file to
  Sources
* Tue Oct 29 2013 pgajdos@suse.com
- /etc/protocols: assign 4 to ipv4 instead of ip to correspond with
  IANA [bnc#843511] (internal)
* Thu Aug 22 2013 pgajdos@suse.com
- updated to newer (not newest) version of IANA assignments
  [bnc#831522], [bnc#731391] (both internal)
* Wed Jun  5 2013 pgajdos@suse.com
- services: map sieve to 4190 instead of 2000 as upstream (IANA)
  does
* Mon Mar  7 2011 ro@suse.de
- bump version to 11.5
* Thu Mar  3 2011 pgajdos@suse.cz
- added COPYING file (cfarrell@suse.de)
* Thu Nov  4 2010 pgajdos@suse.cz
- reverted rquotad port assigment [bnc#637382]
  * modified services-suse.diff back to previous state
* Thu Oct 21 2010 pgajdos@suse.cz
- assigned port 4003 to rquotad [bnc#637382]
  * modified services-suse.diff
* Thu Oct 23 2008 pgajdos@suse.cz
- commented out
  spr-itunes        0/tcp    # Shirt Pocket netTunes
  spl-itunes        0/tcp    # Shirt Pocket launchTunes
  lines [bnc#435600]
* Mon Sep  8 2008 pgajdos@suse.cz
- /etc/services and /etc/protocols was marked as %%config(noreplace)
  [bnc#422884]
* Tue Mar 25 2008 mkoenig@suse.de
- add rpcbind alias for sunrpc [fate#300607]
* Tue Mar  4 2008 pgajdos@suse.cz
- added swat 901/tcp back to the suse.patch [#362590]
* Mon Jan 28 2008 kukuk@suse.de
- Update services file from IANA [bnc#352665]
- Fix PreReqs
* Wed Oct  4 2006 kukuk@suse.de
- Update services file from IANA
* Tue May 23 2006 kukuk@suse.de
- Update protocols and services files from IANA
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 14 2005 kukuk@suse.de
- Update services file
* Mon Sep 12 2005 mmj@suse.de
- Readd the correct services file to patch
* Mon Sep 12 2005 mmj@suse.de
- Add IANA official git port (9418) to services
* Thu Jul  7 2005 kukuk@suse.de
- Update services file
* Tue Mar  8 2005 kukuk@suse.de
- Change comments to make peopleusing file wrongly happy [#71247]
* Wed Feb 23 2005 kukuk@suse.de
- Update /etc/services from IANA
* Tue May 11 2004 mmj@suse.de
- Add example for mlmmj list in /etc/aliases
* Fri Apr 16 2004 kukuk@suse.de
- Add smtps back again, got lost with last update
* Fri Apr  2 2004 kukuk@suse.de
- Use linux.site instead of linux.local [Bug #36949]
* Wed Mar 31 2004 mls@suse.de
- add link-local network
* Mon Mar 29 2004 kukuk@suse.de
- Comment out shilp entry to make reading tcpdump output easier
  [Bug #37359]
* Sun Feb 15 2004 kukuk@suse.de
- Update etc/services file with IANA version
* Mon Dec  1 2003 kukuk@suse.de
- Add etc/netgroup (moved from aaa_base)
* Thu Nov 13 2003 adrian@suse.de
- add registered services to service file
  ( sane, distcc, svn )
* Mon Sep  1 2003 draht@suse.de
- added apcupsd daemons to /etc/hosts.allow (#29646)
* Fri Aug 15 2003 kukuk@suse.de
- Make rpm -V quiet
* Tue May 13 2003 kukuk@suse.de
- Remove inetd.conf, is now part of inetd package
* Thu Apr 24 2003 olh@suse.de
- run tftp via tcpd, not in.tftpd
* Tue Apr 15 2003 ro@suse.de
- change version numbering
* Tue Apr 15 2003 arvin@suse.de
- added pop3s and imaps services to inetd.conf (bug #26281)
* Tue Mar 11 2003 kukuk@suse.de
- Add aaa_base to PreReq. to fix update problems [Bug #25102]
* Thu Feb 13 2003 meissner@suse.de
- Add VNC httpd and 2 VNC display ports, which start Xvnc on demand.
* Mon Jan 27 2003 kukuk@suse.de
- Add etc/ethers [Bug #23016]
* Thu Oct 24 2002 kukuk@suse.de
- etc/services: Add lotusnotes alias to lotusnote [Bug #21145]
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Sep  4 2002 kukuk@suse.de
- etc/services: Add ports for sieve and smtps
* Mon Aug 26 2002 kukuk@suse.de
- etc/services: add mrt entry in temporary area
* Fri Aug 23 2002 kukuk@suse.de
- Fix pop2 daemon name, add imap pop3 daemon [Bug #14474]
* Thu Aug 15 2002 kukuk@suse.de
- Add PreRequires [Bug #17899]
* Sat Aug  3 2002 kukuk@suse.de
- etc/services: add rpcbind alias to sunrpc entry
* Tue Jul 30 2002 kukuk@suse.de
- Fix get_version_number.sh
* Mon Jul 22 2002 adrian@suse.de
- add disabled fam daemon line to inetd.conf
- remove KDE 2 talk daemon lines
  (not anymore support due to security issues)
* Wed Jul 17 2002 kukuk@suse.de
- Remove etc/defaultdomian.rpmnew if empty in postinstall script
* Fri Jul 12 2002 kukuk@suse.de
- Add /etc/aliases as config(noreplace).
* Fri Jul  5 2002 kukuk@suse.de
- Update /etc/services (add new, official ports)
* Tue Jul  2 2002 kukuk@suse.de
- fix typo in /etc/services [Bug #16478]
* Thu Jun 13 2002 draht@suse.de
- removed lprold from the comments in /etc/hosts.allow.
* Thu Jun 13 2002 draht@suse.de
- redo change from Tue Feb  5 18:38:44 MET 2002 - draht@suse.de
  commented out services time, telnet, login, finger from default
  /etc/inetd.conf. No services are configured by default.
* Wed May 15 2002 kssingvo@suse.de
- Add cups-lpd entry to inetd.conf (commented out)
* Wed Mar 13 2002 kukuk@suse.de
- Remove not supported entries [Bug #14932]
* Tue Mar  5 2002 kukuk@suse.de
- Add inofficial entries for pbs to etc/services [Bug #14450]
* Fri Mar  1 2002 kukuk@suse.de
- Add sap db entries back to etc/services
* Wed Feb 13 2002 werner@suse.de
- Add the options '-L sendmail' and '-Am' to be sure that
  sendmail does work as server not as msp client
* Tue Feb  5 2002 draht@suse.de
- revert changes in /etc/inetd.conf
* Tue Feb  5 2002 draht@suse.de
- more descriptive comment in /etc/exports.
* Tue Feb  5 2002 draht@suse.de
- Added users db4web dpbox ingres mail oracle perforce pop sapdb
  squid vscan wnn wwwrun and zope to /etc/ftpusers.
  No users removed, legacy users stay.
* Tue Feb  5 2002 draht@suse.de
- commented out services telnet, login and finger from default
  /etc/inetd.conf file.
* Tue Feb  5 2002 draht@suse.de
- add list of wrapped services and examples to /etc/hosts.allow
- changed comment on /etc/hosts.deny
* Tue Feb  5 2002 kukuk@suse.de
- Fix x11 entry in etc/services
* Fri Feb  1 2002 draht@suse.de
- removed ^m characters from etc/services
* Tue Jan 22 2002 kukuk@suse.de
- Sync protocols with official list [Bug #12870]
- Sync services with official list
* Fri Jan 18 2002 kukuk@suse.de
- disable talk, not in wide use today
- amindexd and amidxtaped should run as user amanda [Bug #12619]
* Wed Jan 16 2002 ro@suse.de
- fixed filelist
* Wed Jan 16 2002 kukuk@suse.de
- Remove /var/adm/setup, diphost and add defaultdomain and HOSTNAME
* Mon Oct 22 2001 mmj@suse.de
- Change inetd.conf to have vsftpd support
* Mon Jul 30 2001 kukuk@suse.de
- Fix typo in hosts.equiv [Bug #9420]
* Tue Jul 10 2001 kukuk@suse.de
- Change inetd.conf entry for tftp to match new version
* Fri Jul  6 2001 kukuk@suse.de
- Fix path to initscript in comment
* Tue Jun  5 2001 kukuk@suse.de
- services: Add ksysguard
* Wed May  9 2001 kukuk@suse.de
- Don't send wrong email about changed ftp server
- Fix english comment in inetd.conf [Bug #7913]
* Mon Apr 30 2001 ro@suse.de
- added sql6 as 7210/tcp to etc/services
* Fri Apr 20 2001 kukuk@suse.de
- Add comments for use of ktalkd [Bug #6566]
* Wed Apr 11 2001 kukuk@suse.de
- Revert some of the last changes [Bug #6957]
* Mon Mar 26 2001 kukuk@suse.de
- Update etc/protocols from official iana list [Bug #4183]
* Sat Mar 24 2001 kukuk@suse.de
- etc/services: Add canna entry
* Thu Mar 22 2001 kukuk@suse.de
- Fix example in hosts.allow
- etc/inetd.conf: Only enable time, telnet, rlogin and talk.
* Fri Feb  9 2001 schwab@suse.de
- Fix cvs pserver example (#6293).
* Thu Dec 14 2000 ro@suse.de
- removed lines db2cdb2inst1 and db2idb2inst1 from etc/services (#4461)
* Sat Nov 18 2000 kukuk@suse.de
- Add dqs entries for nashif@suse.de
* Wed Sep 27 2000 kukuk@suse.de
- Add more Wnn* entries to etc/services
* Fri Jul 28 2000 kukuk@suse.de
- Fix rsync example
* Mon Jun 19 2000 kukuk@suse.de
- Compress tar archive
* Mon Jun 19 2000 kukuk@suse.de
- Enable swat in etc/inetd.conf
* Fri May 26 2000 kukuk@suse.de
- Fix tar archive
* Thu May 25 2000 kukuk@suse.de
- Add etc/host.conf
* Mon May 15 2000 kukuk@suse.de
- Remove ypserv entries from hosts.allow/hosts.deny
* Mon May 15 2000 ro@suse.de
- removed duplicate line for opalis-rdv
* Mon May 15 2000 kukuk@suse.de
- etc/services: Add procstatd entry
- etc/inetd.conf: Likewise.
* Tue May  9 2000 ro@suse.de
- added services entry for codine_commd
  (inofficial 536/tcp)
* Mon Apr 17 2000 kukuk@suse.de
- etc/inetd.conf: Change tftpd default configuration to make a
  chroot into tftpboot directory
* Wed Apr  5 2000 kukuk@suse.de
- etc/services: Add more entries
* Wed Apr  5 2000 kukuk@suse.de
- etc/inetd.conf: service name is imap, not imap2 [Bug 2607]
* Mon Mar 13 2000 kukuk@suse.de
- etc/services: Now really fix axnet entry [Bug 2080]
* Fri Feb 25 2000 garloff@suse.de
- cvs entry fixed: path to cvs added.
* Fri Feb 25 2000 kukuk@suse.de
- etc/services: Add more entries [Bug 2080]
* Sun Feb 20 2000 garloff@suse.de
- added commented entry for cvs-pserver to inet.conf
* Wed Feb 16 2000 kukuk@suse.de
- etc/services: Add pbs entries
* Tue Feb 15 2000 kukuk@suse.de
- etc/inetd.conf: fix some typos
* Thu Jan 20 2000 kukuk@suse.de
- Add missing amanda client entry to etc/inetd.conf
* Wed Jan 19 2000 kukuk@suse.de
- Add missing amanda idx entries to etc/services
* Thu Jan 13 2000 kukuk@suse.de
- etc/ftpusers: Add more systemuser from /etc/passwd
* Thu Jan 13 2000 kukuk@suse.de
- Add IPv6 addresses to etc/hosts
* Tue Jan 11 2000 kukuk@suse.de
- etc/services: Add db2 and http-rman entries
* Mon Jan  3 2000 kukuk@suse.de
- etc/inetd.conf: Remove RPC entries
- etc/protocols: Add IPv6
- etc/services: Add all known services
- etc/rpc: Removed, is in shlibs
* Thu Oct 21 1999 kukuk@suse.de
- etc/inetd.conf: fix comments, disable btx and rplay
- etc/ftpusers: Add more system users
- etc/services: Add more official assinged numbers
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sat Sep 11 1999 kukuk@suse.de
- Make in.ftpd default ftp daemon (fixes bug #268)
* Thu Sep  2 1999 kukuk@suse.de
- Don't start identd from inetd
* Mon Jul 12 1999 bs@suse.de
- fixed buglet in %%post (create var/adm/notify/messages)
* Mon Jul 12 1999 ro@suse.de
- updated etc/services (added https, ftp, data)
* Tue May 25 1999 uli@suse.de
- added services/inetd.conf entries for Mimer
* Tue Mar 30 1999 bs@suse.de
- enabled time services in /etc/inetd.conf
* Mon Mar 22 1999 bs@suse.de
- added "bin" and "daemon" to /etc/ftpusers
* Tue Mar  9 1999 ro@suse.de
- /etc/services: added entries for IBM DB2 Database
* Tue Mar  2 1999 ro@suse.de
- glibc is libc.so.6.1 on alpha: no etc/rpc there
* Wed Jan 13 1999 bs@suse.de
- added some entries for samba to inetd.conf and services
* Sat Dec  5 1998 bs@suse.de
- added netplan to /etc/services
- marked /etc/inetd.conf as noreplace
* Sat Nov 28 1998 bs@suse.de
- added rsync to etc/services and etc/inetd.conf
* Wed Nov 18 1998 bs@suse.de
- disabled vbox in inetd.conf
* Tue Nov 17 1998 bs@suse.de
- hosts.equiv: typo fix
- etc/services:  added afpovertcp, mysql
- etc/inetd.conf:  added leafnode, vboxd
    removed in.nntpd
* Fri Aug 21 1998 bs@suse.de
- added some entries to /etc/services to be friendly for netatalk
* Mon Aug 17 1998 bs@suse.de
- changed entry for rplayd in inetd.conf
* Tue Jul 28 1998 bs@suse.de
- changed comment headers in /etc/hosts and /etc/hosts.lpd
- added "noreplace" feature.
* Mon Jul 13 1998 bs@suse.de
- inetd.conf
  - added new entry for rplay
  - added entry for proftpd
- services:
  - added aliases for imap2 (imap, imap4)
* Thu May 28 1998 bs@suse.de
- disabled imap2 in /etc/inetd.conf
* Tue Mar  3 1998 ro@suse.de
- etc/services     - changed entry for http-rman to nowait.10000
* Sat Feb 28 1998 ro@suse.de
- etc/services     - added entried for radius
* Mon Feb  9 1998 bs@suse.de
- etc/services:    - added entries for amanda
  - added entries for ssh
- etc/inetd.conf:  - added entries for amanda
  - added "-e" to /usr/sbin/in.identd
  - added comment for "keep-alive"
* Wed Jan 28 1998 ro@suse.de
- changed ftpd from in.ftpd to wu.ftpd in /etc/inetd.conf
  (in case of update with existing in.ftpd and nonexisting
  wu.ftpd, the administrator is notified of the change)
* Mon Jan 26 1998 ro@suse.de
- added entries for hp eloquence software 8010,8100,8102,8104
